@@ -1,5 +1,5 @@
 package Config::From::Backend::DBIx;
-$Config::From::Backend::DBIx::VERSION = '0.03';
+$Config::From::Backend::DBIx::VERSION = '0.04';
 
 use utf8;
 use Moose;
@@ -55,6 +55,29 @@ sub _build_config_node {
     return $config;
 }
 
+=head1 NAME
 
+Config::From::Backend::DBIx -  DBIx Backend for Config::From
+
+
+=head1 VERSION
+
+version 0.04
+
+=head1 SYNOPSIS
+
+    my $bckdbix = Config::From::Backend::DBIx->new(schema => $schema, table => 'Config');
+
+    my $config = $bckdbix->datas
+
+=head1 SUBROUTINES/METHODS
+
+
+
+=head1 AUTHOR
+
+Daniel Brosseau, C<< <dab at catapulse.org> >>
+
+=cut
 
 1; # End of Config::From::Backend::File
