@@ -1,5 +1,5 @@
 package Config::From::Backend::File;
-$Config::From::Backend::File::VERSION = '0.03';
+$Config::From::Backend::File::VERSION = '0.04';
 
 use utf8;
 use Moose;
@@ -32,5 +32,29 @@ sub _build_datas {
     return $config;
 }
 
+=head1 NAME
+
+Config::From::Backend::File -  File Backend for Config::From
+
+
+=head1 VERSION
+
+version 0.04
+
+=head1 SYNOPSIS
+
+    my $bckfile = Config::From::Backend::File->new(file => 't/conf/file1.yml');
+
+    my $config = $bckfile->datas
+
+=head1 SUBROUTINES/METHODS
+
+
+=head1 AUTHOR
+
+Daniel Brosseau, C<< <dab at catapulse.org> >>
+
+=cut
+
 
 1; # End of Config::From::Backend::File
